==> kyua-0.11.tar.gz: kyua-0.11/utils/env.hpp <==
// Copyright 2010 Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// * Redistributions of source code must retain the above copyright
//   notice, this list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the
//   documentation and/or other materials provided with the distribution.
// * Neither the name of Google Inc. nor the names of its contributors
//   may be used to endorse or promote products derived from this software
//   without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

/// \file utils/env.hpp
/// Querying and manipulation of environment variables.
///
/// These utility functions wrap the system functions to manipulate the
/// environment in a portable way and expose their arguments and return values
/// in a C++-friendly manner.

#if !defined(UTILS_ENV_HPP)
#define UTILS_ENV_HPP

#include <map>
#include <string>

#include "utils/optional.hpp"

namespace utils {


namespace fs {
class path;
}  // namespace fs


std::map< std::string, std::string > getallenv(void);
optional< std::string > getenv(const std::string&);
std::string getenv_with_default(const std::string&, const std::string&);
optional< utils::fs::path > get_home(void);
void setenv(const std::string&, const std::string&);
void unsetenv(const std::string&);


}  // namespace utils

#endif  // !defined(UTILS_ENV_HPP)

==> kyua-0.14.1.tar.gz: kyua-0.14.1/utils/env.hpp <==
// Copyright 2010 The Kyua Authors.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// * Redistributions of source code must retain the above copyright
//   notice, this list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the
//   documentation and/or other materials provided with the distribution.
// * Neither the name of Google Inc. nor the names of its contributors
//   may be used to endorse or promote products derived from this software
//   without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

/// \file utils/env.hpp
/// Querying and manipulation of environment variables.
///
/// These utility functions wrap the system functions to manipulate the
/// environment in a portable way and expose their arguments and return values
/// in a C++-friendly manner.

#if !defined(UTILS_ENV_HPP)
#define UTILS_ENV_HPP

#include <map>
#include <string>

#include "utils/fs/path_fwd.hpp"
#include "utils/optional_fwd.hpp"

namespace utils {


std::map< std::string, std::string > getallenv(void);
optional< std::string > getenv(const std::string&);
std::string getenv_with_default(const std::string&, const std::string&);
optional< utils::fs::path > get_home(void);
void setenv(const std::string&, const std::string&);
void unsetenv(const std::string&);


}  // namespace utils

#endif  // !defined(UTILS_ENV_HPP)
